@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2 -*- */
 /*
-  Copyright(C) 2011-2017 Kouhei Sutou <kou@clear-code.com>
+  Copyright(C) 2011-2018 Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -253,6 +253,10 @@
 #  define MRN_HAVE_PSI_MEMORY_KEY
 #endif
 
+#ifdef HAVE_PSI_INTERFACE
+#  define MRN_HAVE_PSI_FILE_KEY
+#endif
+
 #ifdef MRN_HAVE_PSI_MEMORY_KEY
 #  define mrn_my_malloc(size, flags) \
   my_malloc(mrn_memory_key, size, flags)
@@ -279,6 +283,8 @@
 
 #if MYSQL_VERSION_ID >= 50706 && !defined(MRN_MARIADB_P)
 #  define MRN_THD_DB_PATH(thd) ((thd)->db().str)
+#elif defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100306
+#  define MRN_THD_DB_PATH(thd) ((thd)->db.str)
 #else
 #  define MRN_THD_DB_PATH(thd) ((thd)->db)
 #endif
@@ -346,14 +352,21 @@
 #endif
 
 #if defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100000
-#  if MYSQL_VERSION_ID >= 100104
-#    define mrn_init_sql_alloc(thd, mem_root)                           \
+#  if MYSQL_VERSION_ID >= 100306
+#    define mrn_init_sql_alloc(thd, name, mem_root)                     \
+  init_sql_alloc(mem_root,                                              \
+                 name,                                                  \
+                 TABLE_ALLOC_BLOCK_SIZE,                                \
+                 0,                                                     \
+                 MYF(thd->slave_thread ? 0 : MY_THREAD_SPECIFIC))
+#  elif MYSQL_VERSION_ID >= 100104
+#    define mrn_init_sql_alloc(thd, name, mem_root)                     \
   init_sql_alloc(mem_root,                                              \
                  TABLE_ALLOC_BLOCK_SIZE,                                \
                  0,                                                     \
                  MYF(thd->slave_thread ? 0 : MY_THREAD_SPECIFIC))
 #  else
-#    define mrn_init_sql_alloc(thd, mem_root)           \
+#    define mrn_init_sql_alloc(thd, name, mem_root)      \
   init_sql_alloc(mem_root,                              \
                  TABLE_ALLOC_BLOCK_SIZE,                \
                  0,                                     \
@@ -361,13 +374,13 @@
 #  endif
 #else
 #  if MYSQL_VERSION_ID >= 50709
-#    define mrn_init_sql_alloc(thd, mem_root)           \
+#    define mrn_init_sql_alloc(thd, name, mem_root)     \
   init_sql_alloc(mrn_memory_key,                        \
                  mem_root,                              \
                  TABLE_ALLOC_BLOCK_SIZE,                \
                  0)
 #  else
-#    define mrn_init_sql_alloc(thd, mem_root)           \
+#    define mrn_init_sql_alloc(thd, name, mem_root)     \
   init_sql_alloc(mem_root,                              \
                  TABLE_ALLOC_BLOCK_SIZE,                \
                  0)
@@ -586,3 +599,10 @@
        (field->vcol_info->expr_item->save_in_field(field, 0))
 #  endif
 #endif
+
+#ifdef MRN_PERCONA_P
+#  if ((MYSQL_VERSION_ID >= 50634) && (MYSQL_VERSION_ID < 50700)) || \
+      (MYSQL_VERSION_ID >= 50721)
+#    define MRN_HAVE_DB_TYPE_ROCKSDB
+#  endif
+#endif
