@@ -944,7 +944,9 @@ MRN_SHARE *mrn_get_share(const char *table_name, TABLE *table, int *error)
         share->wrap_primary_key = MAX_KEY;
       }
       memcpy(wrap_table_share, table->s, sizeof(*wrap_table_share));
-      mrn_init_sql_alloc(current_thd, &(wrap_table_share->mem_root));
+      mrn_init_sql_alloc(current_thd,
+                         "mroonga::wrap-table-share",
+                         &(wrap_table_share->mem_root));
       wrap_table_share->keys = share->wrap_keys;
       wrap_table_share->key_info = share->wrap_key_info;
       wrap_table_share->primary_key = share->wrap_primary_key;
@@ -1075,8 +1077,15 @@ TABLE_SHARE *mrn_create_tmp_table_share(TABLE_LIST *table_list, const char *path
   char key[MAX_DBKEY_LENGTH];
   key_length = create_table_def_key(thd, key, table_list, FALSE);
 #endif
-#if MYSQL_VERSION_ID >= 100002 && defined(MRN_MARIADB_P)
-  share = alloc_table_share(table_list->db, table_list->table_name, key,
+#if MYSQL_VERSION_ID >= 100306 && defined(MRN_MARIADB_P)
+  share = alloc_table_share(table_list->db.str,
+                            table_list->table_name,
+                            key,
+                            key_length);
+#elif MYSQL_VERSION_ID >= 100002 && defined(MRN_MARIADB_P)
+  share = alloc_table_share(table_list->db,
+                            table_list->table_name,
+                            key,
                             key_length);
 #else
   share = alloc_table_share(table_list, key, key_length);
